# 微博相册下载小工具

![image](https://wx2.sinaimg.cn/mw690/878a37e0gy1fz3yijnh9ej21hi1tie81.jpg)

## 使用说明

* 在根目录下新建一个名为"cookies.txt"的文本文件，将浏览器中的cookies复制到该文件中
* 下载cURL的命令行工具，并设置到环境变量中
* 使用命令行操作，可以使用--help命令查看各选项
